//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	LinearlyInterpolatedPointsCurve.h
//
//	CHANGE HISTORY:
//		MB, 1999-??-??: 1.0.0: - first version
//
//	DESCRIPTION:
//		Implementation of an InterpolatedPointsCurve, which will linearly
//		interpolate between the points in the map.
//
//	AUTHOR:
//		Marco Beijersbergen (MB), cosine (mbeijers@cosine.nl)
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/xcolorcod/src/LinearlyInterpolatedPointsCurve.h,v 1.2 2000/07/19 12:57:36 ulammers Exp $
//
#ifndef LINEARLY_INTERPOLATED_POINTS_CURVE_H
#define LINEARLY_INTERPOLATED_POINTS_CURVE_H

#include "InterpolatedPointsCurve.h"

template<class X, class Y>
class LinearlyInterpolatedPointsCurve : public InterpolatedPointsCurve<X,Y> {
public:
	Y operator()(const X& x) const {
		const_iterator i = lower_bound(x);
		if (i == end()) {
			const_iterator i = end();
			--i;
			return (*i).second;
		}
		if (i == begin()) return (*begin()).second;
		const_iterator prev = i;
		--prev;
		return (*prev).second +
			(x-(*prev).first)/((*i).first-(*prev).first) *
			((*i).second-(*prev).second);
	}
};

#endif


