//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	TableBasedPseudoRGBImage : RGB image in the form of a table
//
//	DESCRIPTION:
//		A class that represents an RGB image in the form of a table
//		with three columns "RED"/"GREEN"/"BLUE"; can be binned with
//		evselect to get a 2D image.
//
//	CHANGE HISTORY:
//		UL, 2000-07-17: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Mon Jul 17 13:46:09 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/xcolorcod/src/TableBasedPseudoRGBImage.h,v 1.3 2000/11/09 11:01:48 ulammers Exp $
//

#ifndef TABLE_BASED_RGB_IMAGE_H
#define TABLE_BASED_RGB_IMAGE_H

#include "Color.h"
#include "ColorImage.h"
#include "LinearlyInterpolatedPointsCurve.h"
#include "Dal.h"

class TableBasedPseudoRGBImage {
public:
	TableBasedPseudoRGBImage(const string &table,
							 const string &xCol,
							 const string &yCol,
							 const string &eCol,
			 const LinearlyInterpolatedPointsCurve<double,Color> &colorCurve);

	ColorImage *toColorImage() const;

	~TableBasedPseudoRGBImage();

private:
	string		_tempTableName;
	ColumnData	*_cdr,
				*_cdg,
				*_cdb;
	real32		*_r, *_g, *_b;
};

#endif
